unit uVisualFrame;

interface

uses
  Winapi.Windows, Winapi.Messages, System.SysUtils, System.Variants, System.Classes,
  Vcl.Graphics, Vcl.Controls, Vcl.Forms, Vcl.Dialogs, Vcl.StdCtrls, IdBaseComponent, IdComponent, IdTCPConnection,
  IdTCPClient, IdHTTP,


  HTTPApp,
  IdMultipartFormData, FireDAC.Stan.Intf, FireDAC.Stan.Option, FireDAC.Stan.Error, FireDAC.UI.Intf, FireDAC.Phys.Intf,
  FireDAC.Stan.Def, FireDAC.Stan.Pool, FireDAC.Stan.Async, FireDAC.Phys, FireDAC.VCLUI.Wait, Data.DB,
  FireDAC.Comp.Client,

  //MyUnits

  uHTTP_ConnectionParams


  ;



type
  TVisualFrame_HTTP = class(TFrame)

    bSendFile: TButton;
    OpenDialog: TOpenDialog;
    IdHTTP: TIdHTTP;
    FDConnection_External: TFDConnection;
    bCreateDir: TButton;
    SendPOSTParams: TButton;

    procedure bSendFileClick(Sender: TObject);
    procedure bCreateDirClick(Sender: TObject);
    procedure SendPOSTParamsClick(Sender: TObject);

  private
    { Private declarations }

    //Fields
    FHTTP_ConnectionParams:THTTP_ConnectionParams;
    FHTTPServerToRequest:string;
    procedure SendOneFile;
    procedure CreateDirOnServer(dir: string);


    //Methods




  public
    { Public declarations }

   //Fields


   //Methods

   constructor Create(AOwner: TComponent); override;
   destructor Destroy;


   function IsHTTPConnectionOk(var Error:string; var ResponseText:string): boolean;
   procedure DefineServerToRequest;

   //properties


   property HTTP_ConnectionParams:THTTP_ConnectionParams read
   FHTTP_ConnectionParams write FHTTP_ConnectionParams;


   property HTTPServerToRequest:string read FHTTPServerToRequest
   write FHTTPServerToRequest;


  end;

implementation

{$R *.dfm}


//-------------------- Create Destroy

procedure TVisualFrame_HTTP.bCreateDirClick(Sender: TObject);
begin
CreateDirOnServer('SomeDir');
end;

constructor TVisualFrame_HTTP.Create(AOwner: TComponent);
begin
  inherited;

FHTTP_ConnectionParams:=THTTP_ConnectionParams.Create(Self);

end;



destructor TVisualFrame_HTTP.Destroy;
begin
//FreeAndNil(FHTTP_ConnectionParams);
end;


//-------------------------------------



function TVisualFrame_HTTP.IsHTTPConnectionOk(var Error:string; var ResponseText:string ):boolean;


begin


Result:=false;

    try

          IdHTTP.Get(FHTTPServerToRequest); // //for example like http://localhost:40000

          if IdHTTP.ResponseText='HTTP/1.1 200 OK' then
          Result:=true; // <<<< If Succeded

          //Also lets write Response Text
           ResponseText:=IdHTTP.ResponseText;


    except

    on E:Exception do

      begin
      ResponseText:=IdHTTP.ResponseText;
      ShowMessage(E.ClassName + 'error'+E.Message );
      end;


    end;




end;

procedure TVisualFrame_HTTP.DefineServerToRequest;
begin
  // Defining Server To Request
  with FHTTP_ConnectionParams do
  begin
    FHTTPServerToRequest := Protocol + '://' + Host + ':' + Port;
  end;
  //for example like http://localhost:40000
end;





procedure TVisualFrame_HTTP.SendOneFile;

var
  PostData: TIdMultiPartFormDataStream;
  FileName:string;

  Error:string;
  ResponseTest:string;

begin

if not IsHTTPConnectionOk(Error,ResponseTest) then Exit;


 if OpenDialog.Execute then
  FileName:=OpenDialog.FileName;


  if FileName='' then Exit;


  PostData := TIdMultiPartFormDataStream.Create;

  try

    idHTTP.Request.Referer := HTTPServerToRequest+'/sendfile'; // 'http://localhost:40000/sendfile'; //   http://www.link.net/download';
    idHTTP.Request.ContentType := 'multipart/form-data';

  //  PostData.AddFormField('field1', 'msg1');
    PostData.AddFile('attach', FileName, 'application/x-rar-compressed');
  //  PostData.AddFormField('field2', 'msg2');
  //  PostData.AddFormField('action', 'post');

    idHTTP.Post(HTTPServerToRequest+'/sendfile', PostData);

    Application.ProcessMessages;
  finally

    if(Assigned(PostData)) then PostData.Free;
      ShowMessage('idHTTP Sent OK');

  end;


end;



procedure TVisualFrame_HTTP.SendPOSTParamsClick(Sender: TObject);
var
  PostData: TIdMultiPartFormDataStream;
  FileName:string;

  Error:string;
  ResponseTest:string;

begin

if not IsHTTPConnectionOk(Error,ResponseTest) then Exit;

  PostData := TIdMultiPartFormDataStream.Create;

  try

    idHTTP.Request.Referer := HTTPServerToRequest+'/SomeURICommand';
    idHTTP.Request.ContentType := 'multipart/form-data';

    PostData.AddFormField('SomePOSTParam1','SomePostParamValue1');
    PostData.AddFormField('SomePOSTParam2','SomePostParamValue2');

  //  PostData.AddFile('attach', FileName, 'application/x-rar-compressed');
  //  PostData.AddFormField('field2', 'msg2');
  //  PostData.AddFormField('action', 'post');

    idHTTP.Post(HTTPServerToRequest+'/SomeURICommand', PostData);

    Application.ProcessMessages;
  finally

    if(Assigned(PostData)) then PostData.Free;
      ShowMessage('idHTTP Sent OK');

  end;


end;





procedure TVisualFrame_HTTP.CreateDirOnServer(dir:string);
var
  PostData: TIdMultiPartFormDataStream;
  FileName:string;

  Error:string;
  ResponseTest:string;

begin

if not IsHTTPConnectionOk(Error,ResponseTest) then Exit;



  PostData := TIdMultiPartFormDataStream.Create;

  try

    idHTTP.Request.Referer := HTTPServerToRequest+'/CreateDirOnServer'; // 'http://localhost:40000/sendfile'; //   http://www.link.net/download';
    idHTTP.Request.ContentType := 'multipart/form-data';

    PostData.AddFormField('DirectoryToCreate', dir);
  //  PostData.AddFile('attach', FileName, 'application/x-rar-compressed');
  //  PostData.AddFormField('field2', 'msg2');
  //  PostData.AddFormField('action', 'post');

    idHTTP.Post(HTTPServerToRequest+'/CreateDirOnServer', PostData);

    Application.ProcessMessages;
  finally

    if(Assigned(PostData)) then PostData.Free;
      ShowMessage('idHTTP Sent OK');

  end;


end;


procedure TVisualFrame_HTTP.bSendFileClick(Sender: TObject);

begin

 SendOneFile;

end;






end.
